dispatch

Function dispatch 

pub fn dispatch(name: &str, args: &[String]) -> Result<ExitCode, String>
Resolve name in the active generation, locate its real binary in the store, and exec it with args. Returns the child exit code (non-unix) or only returns on failure (unix exec replaces the process).